/*
   Copyright (c) 2005 Lucas Mello Schnorr (schnorr@gmail.com)
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#include <Foundation/Foundation.h>
#include <Paje/Paje.h>

int main(int argc, char **argv)
{
	NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];

	/* Declaring the PajeHeaderCenter */
	PajeHeaderCenter *headerCenter;

	/* Declaring the event that must have a additional fields */
	PajeStartLink *startLink, *startLink2, *startLink3;

	/* Allocating and initalizing the PajeHeaderCenter */
	headerCenter = [[PajeHeaderCenter alloc] initWithDefaultHeader];

	/* Allocating the PajeStartLink */
	startLink = [[PajeStartLink alloc] init];

	/* Adding new fields to PajeStartLink */
	[startLink addFieldNamed: @"Communication Size" withType: @"string"];
	[startLink addFieldNamed: @"Communication Size2" withType: @"string"];
	[startLink addFieldNamed: @"Communication Size3" withType: @"string"];

	/* When setting the value for the new field, do like this: */
	[startLink setValue: @"50KBytes" forFieldNamed: @"Communication Size2"];
	/* Setting the SourceContainer field for PajeStartLink */
	[startLink setSourceContainer: @"SourceContainer"];

	/* Add this different event to PajeHeaderCenter */
	[headerCenter addHeader: [startLink header]];

	/* To use the new event with the "Communication Size" field,
	 * just create events PajeStartLink with the new field.
	 * You don't need to add again at headerCenter,
	 * but that will not harm your program. :)
	 */
	startLink2 = [[PajeStartLink alloc] init];
	[startLink2 addFieldNamed: @"Communication Size" withType: @"string"];

	/* If you need to add more than one field, just do it. */
	[startLink2 addFieldNamed: @"Communication Id" withType: @"string"];


	/* But then you will have to add to headerCenter */
	[headerCenter addHeader: [startLink2 header]];

	/* Other PajeStartLink with a additional field named
	 * "Communication Size". Since We already added to headerCenter
	 * a event with this additional field, we don't have to do it
	 * again.
	 */
	startLink3 = [[PajeStartLink alloc] init];
	[startLink3 addFieldNamed: @"Communication Size" withType: @"string"];

	/* Printing on screen the headers.
	 * Remember: the headers must be the first stuff in a Paj trace file!
	 * If you generate headers after the initialization of your program,
	 * you must wait to the end of libPaje use in your program to
	 * print the headers with [headerCenter print], otherwise your 
	 * header will be incomplete.
	 * */
	NSLog (@"%@", [headerCenter print]);

	/* After printing the header, you can start printing the
	 * events. Don't forget to set all the fields for each event,
	 * otherwise an error will be printed in stderr
	 */
	[startLink setValue: @"Container" forFieldNamed: @"Container"];
	NSLog (@"%@", [[startLink header] fields]);
	NSLog (@"%@", [startLink printWithProvider: headerCenter]);

	[pool release];
	return 0;
}
