/*
   Copyright (c) 2005 Lucas Mello Schnorr (schnorr@gmail.com)
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#include <Foundation/Foundation.h>
#include <Paje/Paje.h>

int main(int argc, char **argv)
{
	NSAutoreleasePool *pool = [[NSAutoreleasePool alloc] init];
	char *hierarchyFileName;

	if (argc == 1) return 1;
	else hierarchyFileName = argv[1];

	/* Declaring the PajeHeaderCenter */
	PajeHeaderCenter *headerCenter;

	/* Allocating and initalizing the PajeHeaderCenter */
	headerCenter = [[PajeHeaderCenter alloc] initWithDefaultHeader];

	/* Allocating an PajeHierarchy object */
	PajeHierarchy *hierarchy = [PajeHierarchy alloc];

	/* Initializing the new allocated object with the hierarchy file name */
	[hierarchy initPajeHierarchyFromFile: [NSString stringWithFormat:
			@"%s", hierarchyFileName]];
	if (hierarchy == nil){
		NSLog (@"error, bad file name");
		return 1;
	}

	/* Get PajeEvent's from the hierarchy */
	NSArray *hierarchyDefinition = [hierarchy hierarchy];
	[hierarchyDefinition retain];

	/* Printing on screen the headers */
	//NSLog (@"%@", [headerCenter print]);


	/* Print on screen the hierarchy definition */
	int i;
	for (i = 0; i < [hierarchyDefinition count]; i++){
		NSLog (@"%@", [[hierarchyDefinition objectAtIndex: i]
					printWithProvider: headerCenter]);
	}
	[hierarchyDefinition release];

	/* From now on, you can use the generation of events based 
	 * on the hierarchy definition
	 */

	/* Example: requesting an alias from the hierarchy */
	NSLog (@"Alias for Thread is: %@", [hierarchy aliasToName: @"Thread"]);
	NSLog (@"Alias for MPICommunication is: %@", [hierarchy aliasToName: @"MPICommunication"]);
	NSLog (@"Alias for mpi_receive is: %@", [hierarchy aliasToName: @"mpi_receive"]);

	
	[pool release];
	return 0;
}
