/**
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#ifndef __PAJECREATECONTAINER_H
#define __PAJECREATECONTAINER_H
#include <Foundation/Foundation.h>
#include "PajeEvent.h"

/**
 * <list>
 * <item><strong>Time</strong> - Time of creation of container</item>
 * <item><strong>Name</strong> - Name of new container</item>
 * <item><strong>Type</strong> - Type of new container</item>
 * <item><strong>Container</strong> - Parent of new container</item>
 * <item><strong>Alias</strong> - Alternative name of new container</item>
 * </list>
 *
 * <p>
 * The <strong>Name</strong> field is the name of the new container created.
 * The <strong>Type</strong> field is the type of container, previously defined
 * with [PajeDefineContainerType] event. The <strong>Container</strong> field
 * must be a pre-created container which encapsulates the new container. The
 * new container can be referenced in future events by the value of 
 * <strong>Alias</strong> and <strong>Name</strong> fields. 
 * The <strong>Time</strong> can be set through the
 * method  [-setTime:]. The others can be set through methods listed below.
 * The simulation of this event instantiates, in
 * the simulation time <strong>Time</strong>, a new container named
 * <strong>Name</strong>, of type <strong>Type</strong>, contained in the pre-existing
 * container <strong>Container</strong>. The field <strong>Type</strong> must have
 * a value corresponding to the <strong>Name</strong> or <strong>Alias</strong> of a
 * previous [PajeDefineContainerType] event. The field <strong>Container</strong>
 * must have a value corresponding to the <strong>Name</strong> or
 * <strong>Alias</strong> of a previous [PajeCreateContainer] event
 * (or <strong>0</strong> or <strong>/</strong>, if on top of the hierarchy).
 * </p>
 */
@interface PajeCreateContainer : PajeEvent
- setAlias: (NSString *) alias;
- setType: (NSString *) type;
- setName: (NSString *) name;
- setContainer: (NSString *) container;
@end


#endif
