/**
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#ifndef __PAJEDEFINELINKTYPE_H
#define __PAJEDEFINELINKTYPE_H
#include <Foundation/Foundation.h>
#include "PajeEvent.h"

/**
 * This event has fields:<br />
 * <list>
 * 	<item><strong>Name</strong> - Name of new link type</item>
 * 	<item><strong>ContainerType</strong> - Type of common ancestral
 * 	container</item>
 * 	<item><strong>SourceContainerType</strong> - Type of source container of
 * 	link</item>
 * 	<item><strong>DestContainerType</strong> - Type of destination container
 * 	of link</item>
 * 	<item><strong>Alias</strong> - Alternative name of new link type</item>
 * </list>
 * 
 * <p>
 * Links are used to display a directed link between two containers such as a
 * communication or the identification of a reaction in a container
 * corresponding to an action on another
 * one. The source and destination
 * containers must have a common ancestral in the container hierarchy
 * (identified by <strong>ContainerType</strong>)
 * All fields can be set through methods
 * listed below.</p>
 */
@interface PajeDefineLinkType : PajeEvent
- setAlias: (NSString *) alias;
- setContainerType: (NSString *) containerType;
- setSourceContainerType: (NSString *) sourceContainerType;
- setDestContainerType: (NSString *) destContainerType;
- setName: (NSString *) name;
@end



#endif
