/**
   Copyright (c) 2005 Lucas Mello Schnorr

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#ifndef __PAJEENDLINK_H
#define __PAJEENDLINK_H
#include <Foundation/Foundation.h>
#include "PajeEvent.h"

/**
 * This event has fields:<br />
 * <list>
 * 	<item><strong>Time</strong> - Time the link started</item>
 * 	<item><strong>EntityType</strong> - Type of link</item>
 * 	<item><strong>Container</strong> - Container that has the link</item>
 * 	<item><strong>DestContainer</strong> - Container where link ended</item>
 * 	<item><strong>Value</strong> - Value of link</item>
 * 	<item><strong>Key</strong> - Used to match to link start</item>
 * </list>
 *
 * <p>
 * The <strong>EntityType</strong> field is the type of link, previously defined
 * with [PajeDefineLinkType] event. The <strong>Container</strong> field must be
 * a pre-created container which encapsulates the link. The
 * <strong>DestContainer</strong> field is the pre-created container where link
 * ends. The <strong>Key</strong> is used to match the end of a link with the
 * its correspoding start (generated by [PajeStartLink]). 
 * During visualization in Paj, at time obtained in <strong>Time</strong>
 * field, this event
 * ends a link to <strong>DestContainer</strong>.
 * The link is of type <strong>EntityType</strong>,
 * which was previously defined by [PajeDefineLinkType].
 * The value of this link is obtained from field <strong>Value</strong> and the
 * last field, <strong>Key</strong>, are used in simulation time to match to the
 * respective [PajeStartLink] event. The link must be inside the
 * <strong>Container</strong> field.
 * The <strong>Time</strong> can be set through the
 * method  [-setTime:]. The others can be set through methods listed below.</p>
 *
 * 
 * <p><strong>Note</strong><br />
 * To the event [PajeEndLink] be matched to the corresponding
 * [PajeStartLink], the fields <strong>Value</strong>, <strong>Key</strong> and
 * <strong>EntityType</strong> should be exactly the same to the ones used at
 * event [PajeStartLink]. The field <strong>DestContainer</strong> and
 * <strong>SourceContainer</strong> doesn't have the obligation to be the same,
 * but they must be under the same type of <strong>Container</strong> in the
 * hierarchy of entities.</p>
 */
@interface PajeEndLink : PajeEvent
- setEntityType: (NSString *) entityType;
- setContainer: (NSString *) container;
- setValue: (NSString *) value;
- setKey: (NSString *) key;
- setDestContainer: (NSString *) destContainer;
@end


#endif
