/**
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#ifndef __PAJEHEADER_H
#define __PAJEHEADER_H
#include <Foundation/Foundation.h>

/**
 * This class defines a single event definition in Paje file format.
 * Normally, this definition is composed of the following lines
 * in a usual Paje trace file
 * <example>
 * %EventDef PajeCreateContainer 1
 * %       Time date
 * %       Alias string
 * %       Type string
 * %       Container string
 * %       Name string
 * %EndEventDef
 * </example>
 * <strong>Note:</strong> This class are not meant to be directly
 * used, since all [PajeEvent] subclasses has a header declared inside.
 */
@interface PajeHeader : NSObject
{
	NSString *myName;
	int myCode;
	NSMutableArray *fields;
}
/**
 * This method returns a string that if printed in a terminal or a file will
 * look like this:
 * <example>
 * %EventDef PajeDefineEntityValue 3
 * %       Alias string
 * %       EntityType string
 * %       Name string
 * %EndEventDef
 * </example>
 */
- (NSString *) print;

/**
 * This method sets the name of the header.
 */
- setName: (NSString *) name;

/**
 * This method sets the code of the header
 */
- setCode: (int) code;

/**
 * This method adds a field to the header.
 */
- (BOOL) addFieldNamed: (NSString *) name withType: (NSString *) type;

/**
 * This method returns the code for the header.
 */
- (int) code;

/**
 * This method returns the name of the header.
 */
- (NSString *) name;

/**
 * This method returns YES if <em>header</em> is equal to the receiver.
 * Otherwise, returns NO.
 */
- (BOOL) isEqual: (PajeHeader *) header;

/**
 * This method returns all the fields of the header. Every position in the array
 * returned is composed of an array with two positions: first for the field
 * name, second for the field type.
 */
- (NSArray *) fields;

/**
 * This method returns a integer that represent how many fields has the header.
 */
- (int) count;
@end
#endif
