/**
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#ifndef __PAJEHEADERCENTER_H
#define __PAJEHEADERCENTER_H
#include <Foundation/Foundation.h>
#include "PajeHeader.h"

/**
 * This class manages the headers for a single Paje trace file.
 * This management is to mantain each event unique, by adding
 * a unique code for each of them. An instance of this class is
 * passed as parameter to [PajeEvent-printWithProvider:].
 */
@interface PajeHeaderCenter : NSObject
{
	NSMutableSet *headers;
}
/**
 * Initializates the default header for a usual Paje trace file.
 */
- (id) initWithDefaultHeader;

/**
 * Returns a string that if printed to a terminal or to a file 
 * will looks like a Paje complete header. To print, it uses 
 * the headers already added or the traditional default headers
 */
- (NSString *) print;

/**
 * Adds a new header, modifies the code for the header to be unique
 */
- (BOOL) addHeader: (PajeHeader *) header;

/**
 * Returns the code for the specified header
 */
- (int) codeForHeader: (PajeHeader *) header;
@end

#include "PajeEvent.h"
#endif
