/**
   Copyright (c) 2005 Lucas Mello Schnorr

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#ifndef __PAJEPUSHSTATE_H
#define __PAJEPUSHSTATE_H
#include <Foundation/Foundation.h>
#include "PajeEvent.h"


/**
 * This event has fields:<br />
 * <list>
 * <item><strong>Time</strong> - Time the state changed</item>
 * <item><strong>EntityType</strong> - Type of state</item>
 * <item><strong>Container</strong> - Container whose state changed</item>
 * <item><strong>Value</strong> - Value of new state of container</item>
 * </list>
 *
 * <p>
 * The field <strong>EntityType</strong> is the identification of this state
 * in the hierarchy of entities and should be previously defined with the 
 * event [PajeDefineStateType]. The <strong>Container</strong> is the
 * identification of container that has the state. The <strong>Value</strong> 
 * field identifies the state to be pushed to the <strong>Container</strong>,
 * and must be previously defined
 * with a [PajeDefineEntityValue] event. 
 * The <strong>Time</strong> can be set through the
 * method  [-setTime:]. The others can be set through methods listed below.</p>
 * <p>
 * <strong>Note</strong><br />
 * The event [PajePushState] normally is used matched with a previously
 * [PajePopState] event.
 * </p>
 */
@interface PajePushState : PajeEvent
- setEntityType: (NSString *) et;
- setContainer: (NSString *) c;
- setValue: (NSString *) v;
@end


#endif
