/*
   Copyright (c) 2005 Lucas Mello Schnorr

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.

*/
#include "PajeEvent.h"

@implementation PajeEvent
- (id) initWithTime: (NSString *) atime
{
	NSLog (@"libPaje(%s): Event %@, method 'initWithTime' must be implemented by the subclasses", __FUNCTION__, self);
	return nil;
}

- setTime: (NSString *) atime
{
	if (time != nil){
		[time release];
	}
	[time = atime retain];
	return;
}

- (NSString *) time
{
	return time;
}

- (int) eventType
{
	return [header code];
}

- subtractFloatTimeByThis: (NSString *) atime
{
	double xx, xxp, res;
	if (atime != nil){
		NSScanner *scanner = [[NSScanner alloc] initWithString: time];
		[scanner scanDouble: &xx];
//		xx = atof ([time cString]);
		[time release];
		NSScanner *scanner2 = [[NSScanner alloc] initWithString: atime];
		[scanner2 scanDouble: &xxp];
//		xxp = atof ([atime cString]);
		res = xx - xxp;
		time = [[NSString alloc] initWithFormat: @"%f", res];
	}else{
		NSLog (@"libPaje(%s): time is nil", __FUNCTION__);
	}
}

- subtractLongTimeByThis: (NSString *) atime
{
	long long xx, xxp, res;
	if (atime != nil){
		xx = atoll ([time cString]);
		[time release];
		xxp = atoll ([atime cString]);
		res = xx - xxp;
		time = [[NSString alloc] initWithFormat: @"%lld", res];
	}else{
		NSLog (@"libPaje(%s): time is nil", __FUNCTION__);
	}
}

- (void) dealloc
{
	[time release];
	[values release];
	[header release];
	[super dealloc];
}

- (BOOL) addFieldNamed: (NSString *) name withType: (NSString *) type
{
	if (name == nil || type == nil){
		NSLog (@"libPaje(%s): Event %@, parameter name(%@) or type(%@) is nil", __FUNCTION__, name, type);
		return NO;
	}
	if ([header addFieldNamed: name withType: type] == NO){
		NSLog (@"libPaje(%s): Event %@, The field \"%@\" (type \"%@\") is already defined", __FUNCTION__, self, name, type);
		return NO;
	}
	return YES;
}

/* voting for deletion */
//- (BOOL) addFieldNamed: (NSString *) name withType: (NSString *) type
//	withValue: (NSString *) value
//{
//	[self addFieldNamed: name withType: type];
//	[values addObject: value];
//	return YES;
//}

- (BOOL) setValue: (NSString *) value forFieldNamed: (NSString *) name
{
	NSArray *headerFields = [header fields];
	NSMutableArray *fields = [[NSMutableArray alloc] init];
	int i;
	for (i = 0; i < [headerFields count]; i++){
		[fields addObject: [[headerFields objectAtIndex: i] objectAtIndex: 0]];
	}

//	NSLog (@"## %@", fields);
	if ([fields containsObject: name] == NO){
		NSLog (@"libPaje(%s): Event %@ doesn't have a field named \"%@\"",
				__FUNCTION__, self, name);
		return NO;
	}
	NS_DURING {
	[values replaceObjectAtIndex: [fields indexOfObject: name] withObject: value];
	}
	NS_HANDLER{
		if ([[localException name] isEqualToString: NSRangeException]){
			int j = [values count];
			int i = [fields indexOfObject: name];
			//NSLog (@"libPaje(%s): Event %@, WARNING: field name \"%@\" hasn't a value, setting to value %@. Exception: %@", __FUNCTION__, self, name, value, [localException reason]);
			//add value correctly
//			NSLog (@"j%d i%d", j, i);
			if (j+1 == i){
				[values addObject: value];
			}else{
				int x;
				for (x = j; x < i-1; x++){
					[values addObject: @""];
				}
				[values addObject: value];
			}
//			NSLog (@"ADDED %@", values);
		}else{
			[localException raise];
		}
	}
	NS_ENDHANDLER
}

- (PajeHeader *) header
{
	return header;
}

- (NSString *) printWithProvider: (PajeHeaderCenter *) provider
{
  int i;
  int code;
  NSMutableString *ret;

  if (provider == nil){
	NSLog(@"libPaje(%s): Event %@, provider is nil", __FUNCTION__, self);
	return nil;	
  }
  
  code = [provider codeForHeader: header];
  if (code == -1){
	NSLog(@"libPaje(%s): Event %@ has header (code=%d) not defined by its provider %@", __FUNCTION__, self, provider, code);
	return nil;	
  }

  if (timeEvent == YES){
	ret = [[NSMutableString alloc] initWithFormat: @"%d %s ",code,[time cString]];
  }else{
  	ret = [[NSMutableString alloc] initWithFormat: @"%d ", code];
  }
  //NSLog (@"%@, values %d", values, [values count]);
  for (i = 0; i < [values count]; i++){
	  if ([[values objectAtIndex: i] isEqual: @""]){
		  NSMutableArray *fieldsNotSet = [[NSMutableArray alloc] init];
		  for (i = 0;i < [values count]; i++){
			if ([[values objectAtIndex: i] isEqual: @""]){
				if (timeEvent == YES){
					[fieldsNotSet addObject: [[header fields] objectAtIndex: i+1]];
				}else{
					[fieldsNotSet addObject: [[header fields] objectAtIndex: i]];
				}
			}
		  }
		NSLog (@"libPaje(%s): Event %@, Cannot printing the event because the value for fields #%@# were NOT set", __FUNCTION__, self, fieldsNotSet);
		[fieldsNotSet release];
		[ret release];
		return  nil;
	  }
	  if ([[values objectAtIndex: i] rangeOfString: @" "].length == 0){
	        [ret appendString: [NSString stringWithFormat: @"%s ", [[values objectAtIndex: i] cString]]];
	  }else{
	        [ret appendString: [NSString stringWithFormat: @"\"%s\" ", [[values objectAtIndex: i] cString]]];
	  }
  }
  [ret autorelease];
  return ret;
}
@end

