/*
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#include "PajeHeader.h"

@implementation PajeHeader 
- (id) init
{
	self = [super init];
	fields = [[NSMutableArray alloc] init];
	myName = nil;
	myCode = -1;
	return self;
}

- (void) dealloc
{
	[fields release];
	[myName release];
	[super dealloc];
}

- (NSString *) print
{
	int i;
	NSMutableString *ret = [NSMutableString string];
	
	[ret appendString: [NSString stringWithFormat: @"%%EventDef %@ %d\n", myName, myCode]];
	for (i = 0; i < [fields count]; i++){
		if ([[[fields objectAtIndex: i] objectAtIndex:0] rangeOfString: @" "].length!=0){
			[ret appendString: [NSString stringWithFormat: @"%%\t\"%@\" %@\n", [[fields objectAtIndex: i] objectAtIndex:0], [[fields objectAtIndex: i] objectAtIndex:1]]];
		}else{
			[ret appendString: [NSString stringWithFormat: @"%%\t%@ %@\n", [[fields objectAtIndex: i] objectAtIndex:0], [[fields objectAtIndex: i] objectAtIndex:1]]];
		}

	}
	[ret appendString: [NSString stringWithFormat: @"%%EndEventDef\n"]];
	return ret;
}

- setName: (NSString *) name
{
	if (myName != nil){
		[myName release];
	}
	[myName = name retain];
}

- setCode: (int) code
{
	myCode = code;
}

- (BOOL) addFieldNamed: (NSString *) name withType: (NSString *) type
{
	NSArray *new;
	if (name == nil || type == nil){
		NSLog (@"libPaje(%s): PajeHeader %@ received named=%@ and type=%@. One of them is nil", __FUNCTION__, self, name, type);
	}
	new = [[NSArray alloc] initWithObjects: name, type, nil];
	NSMutableArray *fieldsName = [[NSMutableArray alloc] init];
	int i;
	for (i = 0; i < [fields count]; i++){
		[fieldsName addObject: [[fields objectAtIndex: i] objectAtIndex: 0]];
	}
	if ([fieldsName containsObject: [new objectAtIndex: 0]]){
		[new release];
		[fieldsName release];
		return NO;
	}
	[fields addObject: new];
	[new release];
	[fieldsName release];
	return YES;
}

- (int) code
{
	return myCode;
}

- (NSString *) name
{
	return myName;
}

- (NSArray *) fields
{
	return fields;
}	

- (BOOL) isEqual: (PajeHeader *) header
{
	NSSet *me, *par;
	BOOL set, str, ret;
	
	me = [NSSet setWithArray: fields];
	par = [NSSet setWithArray: [header fields]];
	set = [me isEqualToSet: par];
	str = [myName isEqual: [header name]];
	ret = str && set;
//	NSLog (@"%@=%@ %@=%@ %d", name, [header name], fields, [header fields],
//		ret);
	return ret;	
}

- (int) count
{
	return [fields count];	
}
@end
