/*
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#include "PajeHierarchy.h"

@implementation PajeHierarchy
- (NSString *) newAliasToName: (NSString *) name
{
	static long long alias = 1;
	NSString *ret;

	ret = [self aliasToName: name];
	if (ret == nil){
		ret = [[NSString alloc] initWithFormat: @"%d", alias];
//		NSLog (@"novo %@ para %@", ret, name);
		[hierarchyAlias setObject: ret forKey: name];
//		NSLog (@"->%@", [hierarchyAlias objectForKey: name]);
		[ret autorelease];
		alias++;
	}
	return ret;
}

- (NSString *) aliasToName: (NSString *) name
{
	//NSLog (@"aliasToName: %@ -> %@", name, hierarchyAlias);
	return [hierarchyAlias objectForKey: name];
}

- (void) dealloc
{
	[hierarchyAlias release];
	[hierarchy release];
	[super dealloc];
}

- (id) initPajeHierarchyFromFile: (NSString *) fileName
{
   NSDictionary *dict;
   self = [super init];

   if (fileName == nil){
	NSLog (@"libPaje(%s): fileName is nil", __FUNCTION__);
	return nil;
   }
   
   hierarchyAlias = [[NSMutableDictionary alloc] init];
   dict = [[NSDictionary alloc] initWithContentsOfFile: fileName];
   if (dict == nil){
	NSLog (@"libPaje(%s): coult not read the contents of file %@. This can happen when the file is not in the property list format.",
			__FUNCTION__, fileName);
	return nil;
   }
   hierarchy = [PajeHierarchyNode nodeWithDictionary: dict
   				andProvider: self
				andFatherAlias: nil];
   if (hierarchy == nil){
	return nil;
   }
	   
   [hierarchy retain];
   [dict release];
   return self;
}

- (NSMutableArray *) hierarchy
{
	if (hierarchy == nil){
		return nil;
	}
	return [hierarchy convert];
}

- (NSArray *) entityOfType: (NSString *) type
{
	NSMutableArray *ret;
	Class atype;

	ret = [[NSMutableArray alloc] init];
	[ret autorelease];
	if (type == nil){
		return ret;
	}
	if ([type isEqual: @"event"]){
		atype = [PajeHierarchyEvent class];
	}else if ([type isEqual: @"state"]){
		atype = [PajeHierarchyState class];
	}else if ([type isEqual: @"container"]){
		atype = [PajeHierarchyContainer class];
	}else if ([type isEqual: @"link"]){
		atype = [PajeHierarchyLink class];
	}else if ([type isEqual: @"variable"]){
		atype = [PajeHierarchyVariable class];
	}else{
		return ret;
	}
	[ret addObjectsFromArray: [hierarchy allEntityOfType: atype]];
	return ret;
}
@end
