/*
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#include "PajeHierarchyContainer.h"

@implementation PajeHierarchyContainer

- (id) initWithDictionary: (NSDictionary *) dict
			andProvider: (id) provider
	  		andFatherAlias: (NSString *) faAlias
{
   NSArray *childrenAux;
   int i;

  // NSLog (@"Container: parent=%@", faAlias);
   self = [super init];

   /* Retaining stuff this instance needs */
   [provider retain];
   
   parentAlias = faAlias;
   [parentAlias retain];

   /* Checking for name */
   name = [dict valueForKey: @"name"];
   [name retain];
   if (name == nil){
     NSLog (@"libPaje(%s): in definition of type 'container', 'name' is required.", __FUNCTION__);
     [provider release];
     [parentAlias release];
     return nil;
   }

   /* Getting an alias for that name */
   myAlias = [provider newAliasToName: name];
   [myAlias retain];

   /* Create the event */
   event = [[PajeDefineContainerType alloc] initWithTime: @"0.0"];
   [event setName: name];
   [event setAlias: myAlias];
   [event setContainerType: parentAlias];
   
   /* Treat children */
   children = [[NSMutableArray alloc] init]; //retained, see .h
   childrenAux = [dict valueForKey: @"children"];
   if (childrenAux == nil){
     NSLog (@"libPaje(%s): in definition of type 'container', name=%@, 'children' key is required", __FUNCTION__, name);
     [name release];
     [myAlias release];
     [parentAlias release];
     [children release];
     return nil;
   }else{
     for (i = 0; i < [childrenAux count]; i++){
        PajeHierarchyNode *ch;
        ch=[PajeHierarchyNode nodeWithDictionary: [childrenAux objectAtIndex: i]
      					andProvider: provider
                                     andFatherAlias: myAlias];
//	NSLog (@"%@ - %@", child, [childrenAux objectAtIndex: i]);
	if (ch == nil){
		return nil;
	}
        [children addObject: ch];
//	[ch release]; //this is an error, because PajeHierarchyNode returns
//	autorelease object, if we release it here, we are releasing the object
//	that was added at children array.
     }
   }
   [provider release];
   return self;
}

- (void) dealloc 
{
  [event release];
  [children release];
  [super dealloc];
}

- (NSMutableArray *) convert
{
   NSMutableArray *ret;
   int i;
   ret = [[NSMutableArray alloc] init];
   [ret addObject: event];
   for (i = 0; i < [children count]; i++){
	[ret addObjectsFromArray: [[children objectAtIndex: i] convert]];
   }
   [ret autorelease];
   return ret;
}

/*
- (NSString *) typeEvent
{
  NSMutableString *ret = [NSMutableString string];
  NSArray *order;
  int i;

  order = [eventDesc order];
  [order retain];

  [ret appendFormat: @"%@ ", [eventDesc pajeSingleEventAlias]];
  for (i = 0; i < [order count]; i++){
    NSString *field = [order objectAtIndex: i];
    if ([field isEqual: NEWTYPE_ALIAS]){
      [ret appendFormat: @"%@ ", alias];
    }else if ([field isEqual: NEWNAME_NAME]){
      [ret appendFormat: @"\"%@\" ", name];
    }else if ([field isEqual: CONTAINERTYPE_CONTAINER]){
      [ret appendFormat: @"%@ ", fatherAlias];
    }
  } 
  [ret appendString: @"\n"];
  for (i = 0; i < [descendents count]; i++){
    [ret appendString: [[descendents objectAtIndex: i] typeEvent]];
  }
  [order release];
  return ret;
}
*/

- (NSMutableArray *) allEntityOfType: (Class) type
{
        NSMutableArray *ret;
	int i;

	ret = [[NSMutableArray alloc] init];
	[ret addObjectsFromArray: [super allEntityOfType: type]];
	for (i = 0; i < [children count]; i++){
		[ret addObjectsFromArray: [[children objectAtIndex: i] allEntityOfType: type]];
	}
	[ret autorelease];
	return ret;
}
@end
