/*
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#include "PajeHierarchyEvent.h"

@implementation PajeHierarchyEvent
- (id) initWithDictionary: (NSDictionary *) dict
              andProvider: (id) provider
	                 andFatherAlias: (NSString *) faAlias;
{
  NSArray *valuesAux;
  int i;

   //NSLog (@"Event: parent=%@", faAlias);
  self = [super init];
  [provider retain];
  parentAlias = faAlias;
  [parentAlias retain];

  /* get name of event */
  name = [dict valueForKey: @"name"];
  if (name == nil){
     NSLog (@"libPaje(%s): in definition of type 'event', 'name' key is required", __FUNCTION__);
     [provider release];
     [parentAlias release];
     return nil;
  }
  [name retain];

  myAlias = [provider newAliasToName: name];
  [myAlias retain];

  event = [[PajeDefineEventType alloc] initWithTime: @"0.0"];
  [event setName: name];
  [event setAlias: myAlias];
  [event setContainerType: parentAlias];

  values = [[NSMutableArray alloc] init];
  valuesAux = [dict valueForKey: @"values"];
  if (valuesAux == nil){
     NSLog (@"libPaje(%s): in definition of type 'event', name=%@, 'values' key is required", __FUNCTION__, name);
     [name release];
     [myAlias release];
     [parentAlias release];
     [values release];
     return nil;
  }else{
    for (i = 0; i < [valuesAux count]; i++){
      PajeHierarchyValue *child;
      child = [[PajeHierarchyValue alloc]
    		initWithDictionary: [valuesAux objectAtIndex: i]
                       andProvider: provider andFatherAlias: myAlias];
      [values addObject: child];
      [child release];
    }
  }
  [provider release];
  return self;
}

- (void) dealloc
{
  [values release];
  [event release];
  [super dealloc];
}

- (NSMutableArray *) convert
{  
   NSMutableArray *ret;
   int i;
   ret = [[NSMutableArray alloc] init];
   [ret addObject: event]; 
   for (i = 0; i < [values count]; i++){
        [ret addObjectsFromArray: [[values objectAtIndex: i] convert]];
   }
   [ret autorelease];
   return ret;
}


/*

- (NSString *) typeEvent
{
  NSMutableString *ret = [NSMutableString string];
  NSArray *order;
  int i;

  order = [eventDesc order];
  [order retain];
  [ret appendFormat: @"%@ ", [eventDesc pajeSingleEventAlias]];
  for (i = 0; i < [order count]; i++){
    NSString *field = [order objectAtIndex: i];
    if ([field isEqual: NEWTYPE_ALIAS]){
       [ret appendFormat: @"%@ ", alias];
    }else if ([field isEqual: NEWNAME_NAME]){
       [ret appendFormat: @"\"%@\" ", name];
    }else if ([field isEqual: CONTAINERTYPE_CONTAINER]){
       [ret appendFormat: @"%@ ", fatherAlias];
    }
  }
  [ret appendString: @"\n"];
  for (i = 0; i < [values count]; i++){
    [ret appendString: [[values objectAtIndex: i] typeEvent]];
  }
  [order release];
  return ret;
}

- (NSString *) description
{
  NSMutableString *ret = [NSMutableString string];
  int i;

  [ret appendString: [super description]];
  [ret appendFormat: @" %@\n", name];
  for (i = 0; i < [values count]; i++){
    [ret appendString: [[values objectAtIndex: i] description]];
  }
  return ret;
}

*/
@end
