/*
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#include "PajeHierarchyLink.h"

@implementation PajeHierarchyLink
- (id) initWithDictionary: (NSDictionary *) dict
              andProvider: (PajeHierarchy *) provider
              andFatherAlias: (NSString *) faAlias;
			 
{
  NSArray *valuesAux;
  NSString *dest, *source;
  NSString *sourceContainerType, *destContainerType;
  int i;

   //NSLog (@"Link: parent=%@", faAlias);
   
  self = [super init];
  [provider retain];
  parentAlias = faAlias;
  [parentAlias retain];
  name = [dict valueForKey: @"name"];
  if (name == nil){
     NSLog (@"libPaje(%s): in definition of type 'link', 'name' key is required", __FUNCTION__);
     
     return nil;
  }
  [name retain];

  dest = [dict valueForKey: @"DestContainerType"];
  if (dest == nil){
     NSLog (@"libPaje(%s): in definition of type 'link', name=%@, 'DestContainerType' key is required", __FUNCTION__, name);
     return nil;
  }
  [dest retain];
 
  source = [dict valueForKey: @"SourceContainerType"];
  if (source == nil){
     NSLog (@"libPaje(%s): in definition of type 'link', name=%@, 'SourceContainerType' key is required", __FUNCTION__, name);
     return nil;
  }
  [source retain];

  myAlias = [provider newAliasToName: name];
  [myAlias retain];

  destContainerType = [provider aliasToName: dest];
  if (destContainerType == nil){
	NSLog (@"libPaje(%s): in definition of type 'link', the key 'DestContainerType' (=%@) must point to a defined container. \"%@\" is not defined.", __FUNCTION__, dest, dest);
	return nil;
  }
  [destContainerType retain];
  
  sourceContainerType = [provider aliasToName: source];
  if (sourceContainerType == nil){
	NSLog (@"libPaje(%s): in definition of type 'link', the key 'SourceContainerType' (=%@) must point to a defined container. \"%@\" is not defined.", __FUNCTION__, source,source);
	return nil;
  }
  [sourceContainerType retain];
//  NSLog (@"%@ = %@ %@ = %@", dest,destContainerType, source,sourceContainerType);

  event = [[PajeDefineLinkType alloc] initWithTime: @"0.0"];
  [event setContainerType: parentAlias];
  [event setAlias: myAlias];
  [event setName: name];
  [event setSourceContainerType: sourceContainerType];
  [event setDestContainerType: destContainerType];

  values = [[NSMutableArray alloc] init];
  valuesAux = [dict valueForKey: @"values"];
  if (valuesAux == nil){
     NSLog (@"libPaje(%s): in definition of type 'link', name=%@, 'values' key is required", __FUNCTION__, name);
     return nil;
  }else{
     for (i = 0; i < [valuesAux count]; i++){
        PajeHierarchy *child = [[PajeHierarchyValue alloc] 
 			initWithDictionary: [valuesAux objectAtIndex: i]
                                                      andProvider: provider
                                                   andFatherAlias: myAlias];
        [values addObject: child];
	[child release];
     }
  }
  [provider release];
  [dest release];
  [source release];
  [destContainerType release];
  [sourceContainerType release];
  return self;
}

- (void) dealloc
{
  [values release];
  [event release];
  [super dealloc];
}

- (NSMutableArray *) convert
{
   NSMutableArray *ret;
   int i;
   ret = [[NSMutableArray alloc] init];
   [ret addObject: event];
   for (i = 0; i < [values count]; i++){
        [ret addObjectsFromArray: [[values objectAtIndex: i] convert]];
   }
   [ret autorelease];
   return ret;
}


/*
- (NSString *) typeEvent
{
  NSMutableString *ret = [NSMutableString string];
  NSArray *order;
  int i;

  order = [eventDesc order];
  [order retain];
  [ret appendFormat: @"%@ ", [eventDesc pajeSingleEventAlias]];
  for (i = 0; i < [order count]; i++){
    NSString *field = [order objectAtIndex: i];
    if ([field isEqual: DESTCONTAINERTYPE]){
       [ret appendFormat: @"%@ ", destContainerType];
    }else if ([field isEqual: SOURCECONTAINERTYPE]){
       [ret appendFormat: @"%@ ", sourceContainerType];
    }else if ([field isEqual: NEWNAME_NAME]){
       [ret appendFormat: @"\"%@\" ", name];
    }else if ([field isEqual: CONTAINERTYPE_CONTAINER]){
       [ret appendFormat: @"%@ ", fatherAlias];
    }else if ([field isEqual: NEWTYPE_ALIAS]){
       [ret appendFormat: @"%@ ", alias];
    }
  }
  [ret appendString: @"\n"];
  for (i = 0; i < [values count]; i++){
    [ret appendString: [[values objectAtIndex: i] typeEvent]];
  }
  [order release];
  order = nil;
  return ret;
}

- (NSString *) description
{
  NSMutableString *ret = [NSMutableString string];
  int i;

  [ret appendString: [super description]];
  [ret appendFormat: @" %@\n", name];
  for (i = 0; i < [values count]; i++){
    [ret appendString: [[values objectAtIndex: i] description]];
  }
  return ret;
}
*/
@end
