/*
   Copyright (c) 2005 Lucas Mello Schnorr (schnorr@gmail.com)

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#include "PajeHierarchyNode.h"

@implementation PajeHierarchyNode
+ (PajeHierarchyNode *) nodeWithDictionary: (NSDictionary *) dict
              andProvider: (id) provider
	      andFatherAlias: (NSString *) fatherAlias
{
  NSString *type;
  PajeHierarchyNode *ret;

  type = [dict valueForKey: @"type"];
  if (type == nil){
     ret = [[PajeHierarchyValue alloc] initWithDictionary: dict
                   andProvider: provider andFatherAlias: fatherAlias];
  }else if ([type isEqual: @"event"]){
     ret = [[PajeHierarchyEvent alloc] initWithDictionary: dict
                   andProvider: provider andFatherAlias: fatherAlias];
  }else if ([type isEqual: @"state"]){
     ret = [[PajeHierarchyState alloc] initWithDictionary: dict
                   andProvider: provider andFatherAlias: fatherAlias];
  }else if ([type isEqual: @"container"]){
     ret = [[PajeHierarchyContainer alloc] initWithDictionary: dict
                   andProvider: provider andFatherAlias: fatherAlias];
  }else if ([type isEqual: @"link"]){
     ret = [[PajeHierarchyLink alloc] initWithDictionary: dict
                   andProvider: provider andFatherAlias: fatherAlias];
  }else if ([type isEqual: @"variable"]){
     ret = [[PajeHierarchyVariable alloc] initWithDictionary: dict
                   andProvider: provider andFatherAlias: fatherAlias];
  }else if ([type isEqual: @"root"]){
     ret = [[PajeHierarchyRoot alloc] initWithDictionary: dict
                   andProvider: provider andFatherAlias: fatherAlias];
  }else{
     NSLog (@"libPaje(%s): Paje Hierarchy Type '%@' unknow", __FUNCTION__, type);
     return nil;
  }
  [ret autorelease];
  return ret;
}

- (void) dealloc
{
	[name release];
	[myAlias release];
	[parentAlias release];
	[super dealloc];
}

- (NSMutableArray *) convert
{
	NSLog (@"libPaje(%s): at PajeHierarchyNode, method 'convert' must be implemented by subclasses", __FUNCTION__);
	return nil;
}

- (id) initWithDictionary: (NSDictionary *) dict
       andProvider: (id) provider andFatherAlias: (NSString *) faAlias
{
	NSLog (@"libPaje(%s): at PajeHierarchyNode, method 'initWithDictionary' must be implemented by subclasses", __FUNCTION__);
	return nil;
}

- (NSMutableArray *) allEntityOfType: (Class) type
{
	NSMutableArray *ret;
	int i;

	ret = [[NSMutableArray alloc] init];
	if ([[self class] isMemberOfClass: type]){
		[ret addObject: name];		
	}
	[ret autorelease];
	return ret;
}

@end
