/*
   Copyright (c) 2005 Lucas Mello Schnorr 

   Written by: Lucas Mello Schnorr <schnorr@gmail.com>
   
   This file is part of libPaje.
   
   libPaje is free software; you can redistribute it and/or modify it under
   the terms of the GNU Lesser General Public License as published by the
   Free Software Foundation; either version 2 of the License, or (at your
   option) any later version.
   
   libPaje is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
   for more details.
   
   You should have received a copy of the GNU Lesser General Public License
   along with libPaje; if not, write to the Free Software Foundation, Inc.,
   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
*/
#include "PajeHierarchyRoot.h"

@implementation PajeHierarchyRoot

- (id) initWithDictionary: (NSDictionary *) dict
			andProvider: (id) provider
	  		andFatherAlias: (NSString *) faAlias
{
   NSArray *childrenAux;
   int i;

  // NSLog (@"Container: parent=%@", faAlias);
   self = [super init];

   /* Retaining stuff this instance needs */
   [provider retain];

   if (faAlias != nil){
     	NSLog (@"libPaje(%s): father alias should NOT be nil", __FUNCTION__);
	return nil;
   }

   /* Getting an alias for that name */
   myAlias = @"0";
   [myAlias retain];

   /* Treat children */
   children = [[NSMutableArray alloc] init]; //retained, see .h
   childrenAux = [dict valueForKey: @"children"];
   if (childrenAux == nil){
     NSLog (@"libPaje(%s): in definition of type 'root', 'children' key is required", __FUNCTION__);
     [name release];
     [myAlias release];
     [parentAlias release];
     [children release];
     return nil;
   }else{
     for (i = 0; i < [childrenAux count]; i++){
        PajeHierarchyNode *ch;
        ch=[PajeHierarchyNode nodeWithDictionary: [childrenAux objectAtIndex: i]
      					andProvider: provider
                                     andFatherAlias: myAlias];
//	NSLog (@"%@ - %@", child, [childrenAux objectAtIndex: i]);
	if (ch == nil){
		return nil;
	}
        [children addObject: ch];
//	[ch release]; //this is an error, because PajeHierarchyNode returns
//	autorelease object, if we release it here, we are releasing the object
//	that was added at children array.
     }
   }
   [provider release];
   return self;
}

- (void) dealloc 
{
  [children release];
  [super dealloc];
}

- (NSMutableArray *) convert
{
   NSMutableArray *ret;
   int i;
   ret = [[NSMutableArray alloc] init];
   for (i = 0; i < [children count]; i++){
	[ret addObjectsFromArray: [[children objectAtIndex: i] convert]];
   }
   [ret autorelease];
   return ret;
}

- (NSMutableArray *) allEntityOfType: (Class) type
{
	NSMutableArray *ret;
	int i;

	ret = [[NSMutableArray alloc] init];
	[ret addObjectsFromArray: [super allEntityOfType: type]];
	for (i = 0; i < [children count]; i++){
		[ret addObjectsFromArray: [[children objectAtIndex: i] allEntityOfType: type]];
	}
	[ret autorelease];
	return ret;
}

@end
